<p align="center">

<img  src="https://mk0abtastybwtpirqi5t.kinstacdn.com/wp-content/uploads/picture-solutions-persona-product-flagship.jpg"  width="211"  height="182"  alt="flagship-python"  />

</p>

<h3 align="center">Bring your features to life</h3>

[![python](https://img.shields.io/badge/python-2.7.18%20%7C%203.5%20%7C%203.8-blue.svg)]()
[![codecov](https://codecov.io/gh/flagship-io/flagship-python-sdk/branch/feature/FS2-SettingCodeCov/graph/badge.svg?token=gc96ToiX8G)](https://codecov.io/gh/flagship-io/flagship-python-sdk)
[![Apache2.0](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](http://www.apache.org/licenses/LICENSE-2.0)


**Visit [https://developers.flagship.io/](https://developers.flagship.io/) to get started with Flagship.**

## Docs

- [Installation](https://developers.flagship.io/docs/sdk/python/v2.0#installation)
- [Get Started](https://developers.flagship.io/docs/sdk/python/v2.0#getting-started)
- [Initialize and start](https://developers.flagship.io/docs/sdk/python/v2.0#initialization)
- [Create a visitor](https://developers.flagship.io/docs/sdk/python/v2.0#updating-the-user-context)
- [Campaign integration](https://developers.flagship.io/docs/sdk/python/v2.0#campaign-synchronization)
- [Hit tracking](https://developers.flagship.io/docs/sdk/python/v2.0#hit-tracking)
- [Release Notes](https://developers.flagship.io/docs/sdk/python/v2.0#release-notes)

## Examples

- [Ecommerce App](./examples/ecommerce)

## Contributors

- Raphael Blanadet [@raf-abtasty](https://github.com/raf-abtasty)

## Licence

[Apache License.](https://github.com/abtasty/flagship-python-sdk/blob/master/LICENSE)

## About Flagship
​
<img src="https://www.flagship.io/wp-content/uploads/Flagship-horizontal-black-wake-AB.png" alt="drawing" width="150"/>
​
[Flagship by AB Tasty](https://www.flagship.io/) is a feature flagging platform for modern engineering and product teams. It eliminates the risks of future releases by separating code deployments from these releases :bulb: With Flagship, you have full control over the release process. You can:
​
- Switch features on or off through remote config.
- Automatically roll-out your features gradually to monitor performance and gather feedback from your most relevant users.
- Roll back any feature should any issues arise while testing in production.
- Segment users by granting access to a feature based on certain user attributes.
- Carry out A/B tests by easily assigning feature variations to groups of users.
​
<img src="https://www.flagship.io/wp-content/uploads/demo-setup.png" alt="drawing" width="600"/>
​
Flagship also allows you to choose whatever implementation method works for you from our many available SDKs or directly through a REST API. Additionally, our architecture is based on multi-cloud providers that offer high performance and highly-scalable managed services.
​
**To learn more:**
​
- [Solution overview](https://www.flagship.io/#showvideo) - A 5mn video demo :movie_camera:
- [Documentation](https://docs.developers.flagship.io/) - Our dev portal with guides, how tos, API and SDK references
- [Sign up for a free trial](https://www.flagship.io/sign-up/) - Create your free account
- [Guide to feature flagging](https://www.flagship.io/feature-flags/) - Everything you need to know about feature flag related use cases
- [Blog](https://www.flagship.io/blog/) - Additional resources about release management
